{
  pkgs,
  config,
  lib,
  repoFlake,
  nodeFlake,
  ...
}: let
  inherit (import ../lib.nix {}) mkSimpleTrayService;

  nixpkgs-2211 = nodeFlake.inputs.nixpkgs-2211.legacyPackages.${pkgs.system};
  nixpkgs-unstable-small = nodeFlake.inputs.nixpkgs-unstable-small.legacyPackages.${pkgs.system};
  nixpkgs-wayland' = repoFlake.inputs.nixpkgs-wayland.packages.${pkgs.system};

  wayprompt = nixpkgs-wayland'.wayprompt;
in {
  fonts.fontconfig.enable = true;

  # services.gpg-agent.pinentryFlavor = lib.mkForce null;
  # services.gpg-agent.extraConfig = ''
  #   pinentry-program "${wayprompt}/bin/pinentry-wayprompt"
  # '';

  services = {
    blueman-applet.enable = true;
    network-manager-applet.enable = true;
  };

  systemd.user.targets.tray = {
    Unit = {
      Description = "Home Manager System Tray";
      Requires = ["graphical-session-pre.target"];
    };
  };

  home.packages = with pkgs; [
    # required by network-manager-applet
    pkgs.networkmanagerapplet

    wlr-randr
    wayout
    wl-clipboard
    wmctrl

    wayprompt
    nixpkgs-wayland'.shotman

    # identifies key input syms
    wev

    # TODO: whwat's this for?
    # wltype

    pavucontrol
    playerctl
    pasystray
    qt5.qtwayland
    qt6.qtwayland

    # probably required by flameshot
    # xdg-desktop-portal xdg-desktop-portal-wlr 
    # grim

    (nixpkgs-unstable-small.signal-desktop.overrideAttrs (old: {
      preFixup = old.preFixup + ''
        gappsWrapperArgs+=(
          --add-flags "--enable-features=UseOzonePlatform"
          --add-flags "--ozone-platform=wayland"
        )
      '';
    }))

    ((nixpkgs-unstable-small.session-desktop.override (old: {
        inherit (nixpkgs-2211) appimageTools;
      }))
        .overrideAttrs(old: {
        nativeBuildInputs = old.nativeBuildInputs ++ [
          pkgs.wrapGAppsHook
        ];
        
        preFixup = (old.preFixup or "") + ''
          gappsWrapperArgs+=(
            --add-flags "--enable-features=UseOzonePlatform"
            --add-flags "--ozone-platform=wayland"
          )
        '';
      }))
  ];

  home.sessionVariables = {
    XDG_SESSION_TYPE = "wayland";
    NIXOS_OZONE_WL = "1";
    MOZ_ENABLE_WAYLAND = "1";
  };

  home.pointerCursor = {
    name = "Vanilla-DMZ";
    package = pkgs.vanilla-dmz;
    size = 32;
    x11.enable = true;
    gtk.enable = true;
  };
}
